# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`kafka`](#kafka): This class handles the Kafka requirements.
* [`kafka::broker`](#kafkabroker): This class handles the Kafka (broker).
* [`kafka::consumer`](#kafkaconsumer): This class handles the Kafka (consumer).
* [`kafka::consumer::config`](#kafkaconsumerconfig): This class handles the Kafka (consumer) config.
* [`kafka::mirror`](#kafkamirror): This class handles the Kafka (mirror).
* [`kafka::params`](#kafkaparams): This class provides default parameters.
* [`kafka::producer`](#kafkaproducer): This class handles the Kafka (producer).
* [`kafka::producer::config`](#kafkaproducerconfig): This class handles the Kafka (producer) config.

#### Private Classes

* `kafka::broker::config`: This class handles the Kafka (broker) config.
* `kafka::broker::install`: This class handles the Kafka (broker) package.
* `kafka::broker::service`: This class handles the Kafka (broker) service.
* `kafka::consumer::install`: This class handles the Kafka (consumer) package.
* `kafka::consumer::service`: This class handles the Kafka (consumer) service.
* `kafka::mirror::config`: This class handles the Kafka (mirror) config.
* `kafka::mirror::install`: This class handles the Kafka (mirror) package.
* `kafka::mirror::service`: This class handles the Kafka (mirror) service.
* `kafka::producer::install`: This class handles the Kafka (producer) package.
* `kafka::producer::service`: This class handles the Kafka (producer) service.

### Defined types

* [`kafka::topic`](#kafkatopic): This defined type handles the creation of Kafka topics.

## Classes

### <a name="kafka"></a>`kafka`

This class handles the Kafka requirements.

#### Examples

##### Basic usage

```puppet
class { 'kafka': }
```

#### Parameters

The following parameters are available in the `kafka` class:

* [`kafka_version`](#kafka_version)
* [`scala_version`](#scala_version)
* [`install_dir`](#install_dir)
* [`mirror_url`](#mirror_url)
* [`manage_java`](#manage_java)
* [`package_dir`](#package_dir)
* [`package_name`](#package_name)
* [`mirror_subpath`](#mirror_subpath)
* [`proxy_server`](#proxy_server)
* [`proxy_port`](#proxy_port)
* [`proxy_host`](#proxy_host)
* [`proxy_type`](#proxy_type)
* [`package_ensure`](#package_ensure)
* [`user_name`](#user_name)
* [`user_shell`](#user_shell)
* [`group_name`](#group_name)
* [`system_user`](#system_user)
* [`system_group`](#system_group)
* [`user_id`](#user_id)
* [`group_id`](#group_id)
* [`manage_user`](#manage_user)
* [`manage_group`](#manage_group)
* [`config_dir`](#config_dir)
* [`log_dir`](#log_dir)
* [`install_mode`](#install_mode)

##### <a name="kafka_version"></a>`kafka_version`

Data type: `String[1]`

The version of Kafka that should be installed.

Default value: `$kafka::params::kafka_version`

##### <a name="scala_version"></a>`scala_version`

Data type: `String[1]`

The scala version what Kafka was built with.

Default value: `$kafka::params::scala_version`

##### <a name="install_dir"></a>`install_dir`

Data type: `Stdlib::Absolutepath`

The directory to install Kafka to.

Default value: `$kafka::params::install_dir`

##### <a name="mirror_url"></a>`mirror_url`

Data type: `Stdlib::HTTPUrl`

The url where the Kafka is downloaded from.

Default value: `$kafka::params::mirror_url`

##### <a name="manage_java"></a>`manage_java`

Data type: `Boolean`

Install java if it's not already installed.

Default value: `$kafka::params::manage_java`

##### <a name="package_dir"></a>`package_dir`

Data type: `Stdlib::Absolutepath`

The directory to install Kafka.

Default value: `$kafka::params::package_dir`

##### <a name="package_name"></a>`package_name`

Data type: `Optional[String[1]]`

Package name, when installing Kafka from a package.

Default value: `$kafka::params::package_name`

##### <a name="mirror_subpath"></a>`mirror_subpath`

Data type: `Optional[String[1]]`

The sub directory where the source is downloaded from.

Default value: `$kafka::params::mirror_subpath`

##### <a name="proxy_server"></a>`proxy_server`

Data type: `Optional[String[1]]`

Set proxy server, when installing Kafka from source.

Default value: `$kafka::params::proxy_server`

##### <a name="proxy_port"></a>`proxy_port`

Data type: `Optional[String[1]]`

Set proxy port, when installing Kafka from source.

Default value: `$kafka::params::proxy_port`

##### <a name="proxy_host"></a>`proxy_host`

Data type: `Optional[String[1]]`

Set proxy host, when installing Kafka from source.

Default value: `$kafka::params::proxy_host`

##### <a name="proxy_type"></a>`proxy_type`

Data type: `Optional[String[1]]`

Set proxy type, when installing Kafka from source.

Default value: `$kafka::params::proxy_type`

##### <a name="package_ensure"></a>`package_ensure`

Data type: `String[1]`

Package version or ensure state, when installing Kafka from a package.

Default value: `$kafka::params::package_ensure`

##### <a name="user_name"></a>`user_name`

Data type: `String[1]`

User to run Kafka as.

Default value: `$kafka::params::user_name`

##### <a name="user_shell"></a>`user_shell`

Data type: `Stdlib::Absolutepath`

Login shell of the Kafka user.

Default value: `$kafka::params::user_shell`

##### <a name="group_name"></a>`group_name`

Data type: `String[1]`

Group to run Kafka as.

Default value: `$kafka::params::group_name`

##### <a name="system_user"></a>`system_user`

Data type: `Boolean`

Whether the Kafka user is a system user or not.

Default value: `$kafka::params::system_user`

##### <a name="system_group"></a>`system_group`

Data type: `Boolean`

Whether the Kafka group is a system group or not.

Default value: `$kafka::params::system_group`

##### <a name="user_id"></a>`user_id`

Data type: `Optional[Integer]`

Create the Kafka user with this ID.

Default value: `$kafka::params::user_id`

##### <a name="group_id"></a>`group_id`

Data type: `Optional[Integer]`

Create the Kafka group with this ID.

Default value: `$kafka::params::group_id`

##### <a name="manage_user"></a>`manage_user`

Data type: `Boolean`

Create the Kafka user if it's not already present.

Default value: `$kafka::params::manage_user`

##### <a name="manage_group"></a>`manage_group`

Data type: `Boolean`

Create the Kafka group if it's not already present.

Default value: `$kafka::params::manage_group`

##### <a name="config_dir"></a>`config_dir`

Data type: `Stdlib::Absolutepath`

The directory to create the Kafka config files to.

Default value: `$kafka::params::config_dir`

##### <a name="log_dir"></a>`log_dir`

Data type: `Stdlib::Absolutepath`

The directory for Kafka log files.

Default value: `$kafka::params::log_dir`

##### <a name="install_mode"></a>`install_mode`

Data type: `Stdlib::Filemode`

The permissions for the install directory.

Default value: `$kafka::params::install_mode`

### <a name="kafkabroker"></a>`kafka::broker`

This class handles the Kafka (broker).

#### Examples

##### Basic usage

```puppet
class { 'kafka::broker':
  config => {
    'broker.id'         => '0',
    'zookeeper.connect' => 'localhost:2181'
  }
}
```

#### Parameters

The following parameters are available in the `kafka::broker` class:

* [`kafka_version`](#kafka_version)
* [`scala_version`](#scala_version)
* [`install_dir`](#install_dir)
* [`mirror_url`](#mirror_url)
* [`manage_java`](#manage_java)
* [`package_dir`](#package_dir)
* [`package_name`](#package_name)
* [`package_ensure`](#package_ensure)
* [`user_name`](#user_name)
* [`user_shell`](#user_shell)
* [`group_name`](#group_name)
* [`user_id`](#user_id)
* [`group_id`](#group_id)
* [`manage_user`](#manage_user)
* [`manage_group`](#manage_group)
* [`config_mode`](#config_mode)
* [`config_dir`](#config_dir)
* [`log_dir`](#log_dir)
* [`bin_dir`](#bin_dir)
* [`service_name`](#service_name)
* [`manage_service`](#manage_service)
* [`service_ensure`](#service_ensure)
* [`service_restart`](#service_restart)
* [`service_requires`](#service_requires)
* [`limit_nofile`](#limit_nofile)
* [`limit_core`](#limit_core)
* [`timeout_stop`](#timeout_stop)
* [`exec_stop`](#exec_stop)
* [`daemon_start`](#daemon_start)
* [`env`](#env)
* [`config`](#config)
* [`heap_opts`](#heap_opts)
* [`jmx_opts`](#jmx_opts)
* [`log4j_opts`](#log4j_opts)
* [`opts`](#opts)
* [`manage_log4j`](#manage_log4j)
* [`log_file_size`](#log_file_size)
* [`log_file_count`](#log_file_count)

##### <a name="kafka_version"></a>`kafka_version`

Data type: `String[1]`

The version of Kafka that should be installed.

Default value: `$kafka::params::kafka_version`

##### <a name="scala_version"></a>`scala_version`

Data type: `String[1]`

The scala version what Kafka was built with.

Default value: `$kafka::params::scala_version`

##### <a name="install_dir"></a>`install_dir`

Data type: `Stdlib::Absolutepath`

The directory to install Kafka to.

Default value: `$kafka::params::install_dir`

##### <a name="mirror_url"></a>`mirror_url`

Data type: `Stdlib::HTTPUrl`

The url where the Kafka is downloaded from.

Default value: `$kafka::params::mirror_url`

##### <a name="manage_java"></a>`manage_java`

Data type: `Boolean`

Install java if it's not already installed.

Default value: `$kafka::params::manage_java`

##### <a name="package_dir"></a>`package_dir`

Data type: `Stdlib::Absolutepath`

The directory to install Kafka.

Default value: `$kafka::params::package_dir`

##### <a name="package_name"></a>`package_name`

Data type: `Optional[String[1]]`

Package name, when installing Kafka from a package.

Default value: `$kafka::params::package_name`

##### <a name="package_ensure"></a>`package_ensure`

Data type: `String[1]`

Package version or ensure state, when installing Kafka from a package.

Default value: `$kafka::params::package_ensure`

##### <a name="user_name"></a>`user_name`

Data type: `String[1]`

User to run Kafka as.

Default value: `$kafka::params::user_name`

##### <a name="user_shell"></a>`user_shell`

Data type: `Stdlib::Absolutepath`

Login shell of the Kafka user.

Default value: `$kafka::params::user_shell`

##### <a name="group_name"></a>`group_name`

Data type: `String[1]`

Group to run Kafka as.

Default value: `$kafka::params::group_name`

##### <a name="user_id"></a>`user_id`

Data type: `Optional[Integer]`

Create the Kafka user with this ID.

Default value: `$kafka::params::user_id`

##### <a name="group_id"></a>`group_id`

Data type: `Optional[Integer]`

Create the Kafka group with this ID.

Default value: `$kafka::params::group_id`

##### <a name="manage_user"></a>`manage_user`

Data type: `Boolean`

Create the Kafka user if it's not already present.

Default value: `$kafka::params::manage_user`

##### <a name="manage_group"></a>`manage_group`

Data type: `Boolean`

Create the Kafka group if it's not already present.

Default value: `$kafka::params::manage_group`

##### <a name="config_mode"></a>`config_mode`

Data type: `Stdlib::Filemode`

The permissions for the config files.

Default value: `$kafka::params::config_mode`

##### <a name="config_dir"></a>`config_dir`

Data type: `Stdlib::Absolutepath`

The directory to create the Kafka config files to.

Default value: `$kafka::params::config_dir`

##### <a name="log_dir"></a>`log_dir`

Data type: `Stdlib::Absolutepath`

The directory for Kafka log files.

Default value: `$kafka::params::log_dir`

##### <a name="bin_dir"></a>`bin_dir`

Data type: `Stdlib::Absolutepath`

The directory where the Kafka scripts are.

Default value: `$kafka::params::bin_dir`

##### <a name="service_name"></a>`service_name`

Data type: `String[1]`

Set the name of the service.

Default value: `'kafka'`

##### <a name="manage_service"></a>`manage_service`

Data type: `Boolean`

Install the init.d or systemd service.

Default value: `$kafka::params::manage_service`

##### <a name="service_ensure"></a>`service_ensure`

Data type: `Enum['running', 'stopped']`

Set the ensure state of the service.

Default value: `$kafka::params::service_ensure`

##### <a name="service_restart"></a>`service_restart`

Data type: `Boolean`

Whether the configuration files should trigger a service restart.

Default value: `$kafka::params::service_restart`

##### <a name="service_requires"></a>`service_requires`

Data type: `Array[String[1]]`

Set the list of services required to be running before Kafka.

Default value: `$kafka::params::service_requires`

##### <a name="limit_nofile"></a>`limit_nofile`

Data type: `Optional[String[1]]`

Set the 'LimitNOFILE' option of the systemd service.

Default value: `$kafka::params::limit_nofile`

##### <a name="limit_core"></a>`limit_core`

Data type: `Optional[String[1]]`

Set the 'LimitCORE' option of the systemd service.

Default value: `$kafka::params::limit_core`

##### <a name="timeout_stop"></a>`timeout_stop`

Data type: `Optional[String[1]]`

Set the 'TimeoutStopSec' option of the systemd service.

Default value: `$kafka::params::timeout_stop`

##### <a name="exec_stop"></a>`exec_stop`

Data type: `Boolean`

Set the 'ExecStop' option of the systemd service to 'kafka-server-stop.sh'.

Default value: `$kafka::params::exec_stop`

##### <a name="daemon_start"></a>`daemon_start`

Data type: `Boolean`

Use the '-daemon' option when starting Kafka with 'kafka-server-start.sh'.

Default value: `$kafka::params::daemon_start`

##### <a name="env"></a>`env`

Data type: `Hash`

A hash of the environment variables to set.

Default value: `{}`

##### <a name="config"></a>`config`

Data type: `Hash[String[1], Any]`

A hash of the broker configuration options.

Default value: `{}`

##### <a name="heap_opts"></a>`heap_opts`

Data type: `String[1]`

Set the Java heap size.

Default value: `$kafka::params::broker_heap_opts`

##### <a name="jmx_opts"></a>`jmx_opts`

Data type: `String[1]`

Set the JMX options.

Default value: `$kafka::params::broker_jmx_opts`

##### <a name="log4j_opts"></a>`log4j_opts`

Data type: `String[1]`

Set the Log4j options.

Default value: `$kafka::params::broker_log4j_opts`

##### <a name="opts"></a>`opts`

Data type: `String[0]`

Set the Kafka options.

Default value: `$kafka::params::broker_opts`

##### <a name="manage_log4j"></a>`manage_log4j`

Data type: `Boolean`



Default value: `$kafka::params::manage_log4j`

##### <a name="log_file_size"></a>`log_file_size`

Data type: `Pattern[/[1-9][0-9]*[KMG]B/]`



Default value: `$kafka::params::log_file_size`

##### <a name="log_file_count"></a>`log_file_count`

Data type: `Integer[1, 50]`



Default value: `$kafka::params::log_file_count`

### <a name="kafkaconsumer"></a>`kafka::consumer`

This class handles the Kafka (consumer).

#### Examples

##### Basic usage

```puppet
class { 'kafka::consumer':
  config => {
    'client.id'         => '0',
    'zookeeper.connect' => 'localhost:2181'
  }
}
```

#### Parameters

The following parameters are available in the `kafka::consumer` class:

* [`kafka_version`](#kafka_version)
* [`scala_version`](#scala_version)
* [`install_dir`](#install_dir)
* [`mirror_url`](#mirror_url)
* [`manage_java`](#manage_java)
* [`package_dir`](#package_dir)
* [`package_name`](#package_name)
* [`package_ensure`](#package_ensure)
* [`user_name`](#user_name)
* [`user_shell`](#user_shell)
* [`group_name`](#group_name)
* [`user_id`](#user_id)
* [`group_id`](#group_id)
* [`manage_user`](#manage_user)
* [`manage_group`](#manage_group)
* [`config_mode`](#config_mode)
* [`config_dir`](#config_dir)
* [`log_dir`](#log_dir)
* [`bin_dir`](#bin_dir)
* [`service_name`](#service_name)
* [`manage_service`](#manage_service)
* [`service_ensure`](#service_ensure)
* [`service_restart`](#service_restart)
* [`service_requires`](#service_requires)
* [`limit_nofile`](#limit_nofile)
* [`limit_core`](#limit_core)
* [`env`](#env)
* [`config`](#config)
* [`service_config`](#service_config)
* [`jmx_opts`](#jmx_opts)
* [`log4j_opts`](#log4j_opts)
* [`manage_log4j`](#manage_log4j)
* [`log_file_size`](#log_file_size)
* [`log_file_count`](#log_file_count)

##### <a name="kafka_version"></a>`kafka_version`

Data type: `String[1]`

The version of Kafka that should be installed.

Default value: `$kafka::params::kafka_version`

##### <a name="scala_version"></a>`scala_version`

Data type: `String[1]`

The scala version what Kafka was built with.

Default value: `$kafka::params::scala_version`

##### <a name="install_dir"></a>`install_dir`

Data type: `Stdlib::Absolutepath`

The directory to install Kafka to.

Default value: `$kafka::params::install_dir`

##### <a name="mirror_url"></a>`mirror_url`

Data type: `Stdlib::HTTPUrl`

The url where the Kafka is downloaded from.

Default value: `$kafka::params::mirror_url`

##### <a name="manage_java"></a>`manage_java`

Data type: `Boolean`

Install java if it's not already installed.

Default value: `$kafka::params::manage_java`

##### <a name="package_dir"></a>`package_dir`

Data type: `Stdlib::Absolutepath`

The directory to install Kafka.

Default value: `$kafka::params::package_dir`

##### <a name="package_name"></a>`package_name`

Data type: `Optional[String[1]]`

Package name, when installing Kafka from a package.

Default value: `$kafka::params::package_name`

##### <a name="package_ensure"></a>`package_ensure`

Data type: `String[1]`

Package version or ensure state, when installing Kafka from a package.

Default value: `$kafka::params::package_ensure`

##### <a name="user_name"></a>`user_name`

Data type: `String[1]`

User to run Kafka as.

Default value: `$kafka::params::user_name`

##### <a name="user_shell"></a>`user_shell`

Data type: `Stdlib::Absolutepath`

Login shell of the Kafka user.

Default value: `$kafka::params::user_shell`

##### <a name="group_name"></a>`group_name`

Data type: `String[1]`

Group to run Kafka as.

Default value: `$kafka::params::group_name`

##### <a name="user_id"></a>`user_id`

Data type: `Optional[Integer]`

Create the Kafka user with this ID.

Default value: `$kafka::params::user_id`

##### <a name="group_id"></a>`group_id`

Data type: `Optional[Integer]`

Create the Kafka group with this ID.

Default value: `$kafka::params::group_id`

##### <a name="manage_user"></a>`manage_user`

Data type: `Boolean`

Create the Kafka user if it's not already present.

Default value: `$kafka::params::manage_user`

##### <a name="manage_group"></a>`manage_group`

Data type: `Boolean`

Create the Kafka group if it's not already present.

Default value: `$kafka::params::manage_group`

##### <a name="config_mode"></a>`config_mode`

Data type: `Stdlib::Filemode`

The permissions for the config files.

Default value: `$kafka::params::config_mode`

##### <a name="config_dir"></a>`config_dir`

Data type: `Stdlib::Absolutepath`

The directory to create the Kafka config files to.

Default value: `$kafka::params::config_dir`

##### <a name="log_dir"></a>`log_dir`

Data type: `Stdlib::Absolutepath`

The directory for Kafka log files.

Default value: `$kafka::params::log_dir`

##### <a name="bin_dir"></a>`bin_dir`

Data type: `Stdlib::Absolutepath`

The directory where the Kafka scripts are.

Default value: `$kafka::params::bin_dir`

##### <a name="service_name"></a>`service_name`

Data type: `String[1]`

Set the name of the service.

Default value: `'kafka-consumer'`

##### <a name="manage_service"></a>`manage_service`

Data type: `Boolean`

Install the init.d or systemd service.

Default value: `$kafka::params::manage_service`

##### <a name="service_ensure"></a>`service_ensure`

Data type: `Enum['running', 'stopped']`

Set the ensure state of the service.

Default value: `$kafka::params::service_ensure`

##### <a name="service_restart"></a>`service_restart`

Data type: `Boolean`

Whether the configuration files should trigger a service restart.

Default value: `$kafka::params::service_restart`

##### <a name="service_requires"></a>`service_requires`

Data type: `Array[String[1]]`

Set the list of services required to be running before Kafka.

Default value: `$kafka::params::service_requires`

##### <a name="limit_nofile"></a>`limit_nofile`

Data type: `Optional[String[1]]`

Set the 'LimitNOFILE' option of the systemd service.

Default value: `$kafka::params::limit_nofile`

##### <a name="limit_core"></a>`limit_core`

Data type: `Optional[String[1]]`

Set the 'LimitCORE' option of the systemd service.

Default value: `$kafka::params::limit_core`

##### <a name="env"></a>`env`

Data type: `Hash`

A hash of the environment variables to set.

Default value: `{}`

##### <a name="config"></a>`config`

Data type: `Hash[String[1], Any]`

A hash of the consumer configuration options.

Default value: `{}`

##### <a name="service_config"></a>`service_config`

Data type: `Hash[String[1],String[1]]`

A hash of the `kafka-console-consumer.sh` script options.

Default value: `{}`

##### <a name="jmx_opts"></a>`jmx_opts`

Data type: `String[1]`

Set the JMX options.

Default value: `$kafka::params::consumer_jmx_opts`

##### <a name="log4j_opts"></a>`log4j_opts`

Data type: `String[1]`

Set the Log4j options.

Default value: `$kafka::params::consumer_log4j_opts`

##### <a name="manage_log4j"></a>`manage_log4j`

Data type: `Boolean`



Default value: `$kafka::params::manage_log4j`

##### <a name="log_file_size"></a>`log_file_size`

Data type: `Pattern[/[1-9][0-9]*[KMG]B/]`



Default value: `$kafka::params::log_file_size`

##### <a name="log_file_count"></a>`log_file_count`

Data type: `Integer[1, 50]`



Default value: `$kafka::params::log_file_count`

### <a name="kafkaconsumerconfig"></a>`kafka::consumer::config`

This class handles the Kafka (consumer) config.

#### Parameters

The following parameters are available in the `kafka::consumer::config` class:

* [`manage_service`](#manage_service)
* [`service_name`](#service_name)
* [`service_restart`](#service_restart)
* [`config`](#config)
* [`config_dir`](#config_dir)
* [`user_name`](#user_name)
* [`group_name`](#group_name)
* [`config_mode`](#config_mode)
* [`manage_log4j`](#manage_log4j)
* [`log_file_size`](#log_file_size)
* [`log_file_count`](#log_file_count)

##### <a name="manage_service"></a>`manage_service`

Data type: `Boolean`



Default value: `$kafka::consumer::manage_service`

##### <a name="service_name"></a>`service_name`

Data type: `String[1]`



Default value: `$kafka::consumer::service_name`

##### <a name="service_restart"></a>`service_restart`

Data type: `Boolean`



Default value: `$kafka::consumer::service_restart`

##### <a name="config"></a>`config`

Data type: `Hash[String[1], Any]`



Default value: `$kafka::consumer::config`

##### <a name="config_dir"></a>`config_dir`

Data type: `Stdlib::Absolutepath`



Default value: `$kafka::consumer::config_dir`

##### <a name="user_name"></a>`user_name`

Data type: `String[1]`



Default value: `$kafka::consumer::user_name`

##### <a name="group_name"></a>`group_name`

Data type: `String[1]`



Default value: `$kafka::consumer::group_name`

##### <a name="config_mode"></a>`config_mode`

Data type: `Stdlib::Filemode`



Default value: `$kafka::consumer::config_mode`

##### <a name="manage_log4j"></a>`manage_log4j`

Data type: `Boolean`



Default value: `$kafka::consumer::manage_log4j`

##### <a name="log_file_size"></a>`log_file_size`

Data type: `Pattern[/[1-9][0-9]*[KMG]B/]`



Default value: `$kafka::consumer::log_file_size`

##### <a name="log_file_count"></a>`log_file_count`

Data type: `Integer[1, 50]`



Default value: `$kafka::consumer::log_file_count`

### <a name="kafkamirror"></a>`kafka::mirror`

This class handles the Kafka (mirror).

#### Examples

##### Basic usage

```puppet
class { 'kafka::mirror':
  consumer_config => {
    'group.id'          => 'kafka-mirror',
    'zookeeper.connect' => 'localhost:2181'
  },
  producer_config => {
    'zookeeper.connect' => 'localhost:2181',
  },
  service_config => {
    'whitelist'         => '.*',
  }
}
```

#### Parameters

The following parameters are available in the `kafka::mirror` class:

* [`kafka_version`](#kafka_version)
* [`scala_version`](#scala_version)
* [`install_dir`](#install_dir)
* [`mirror_url`](#mirror_url)
* [`manage_java`](#manage_java)
* [`package_dir`](#package_dir)
* [`package_name`](#package_name)
* [`package_ensure`](#package_ensure)
* [`user_name`](#user_name)
* [`user_shell`](#user_shell)
* [`group_name`](#group_name)
* [`user_id`](#user_id)
* [`group_id`](#group_id)
* [`manage_user`](#manage_user)
* [`manage_group`](#manage_group)
* [`config_mode`](#config_mode)
* [`config_dir`](#config_dir)
* [`log_dir`](#log_dir)
* [`bin_dir`](#bin_dir)
* [`service_name`](#service_name)
* [`manage_service`](#manage_service)
* [`service_ensure`](#service_ensure)
* [`service_restart`](#service_restart)
* [`service_requires`](#service_requires)
* [`limit_nofile`](#limit_nofile)
* [`limit_core`](#limit_core)
* [`env`](#env)
* [`consumer_config`](#consumer_config)
* [`producer_config`](#producer_config)
* [`service_config`](#service_config)
* [`heap_opts`](#heap_opts)
* [`jmx_opts`](#jmx_opts)
* [`log4j_opts`](#log4j_opts)
* [`manage_log4j`](#manage_log4j)
* [`log_file_size`](#log_file_size)
* [`log_file_count`](#log_file_count)

##### <a name="kafka_version"></a>`kafka_version`

Data type: `String[1]`

The version of Kafka that should be installed.

Default value: `$kafka::params::kafka_version`

##### <a name="scala_version"></a>`scala_version`

Data type: `String[1]`

The scala version what Kafka was built with.

Default value: `$kafka::params::scala_version`

##### <a name="install_dir"></a>`install_dir`

Data type: `Stdlib::Absolutepath`

The directory to install Kafka to.

Default value: `$kafka::params::install_dir`

##### <a name="mirror_url"></a>`mirror_url`

Data type: `Stdlib::HTTPUrl`

The url where the Kafka is downloaded from.

Default value: `$kafka::params::mirror_url`

##### <a name="manage_java"></a>`manage_java`

Data type: `Boolean`

Install java if it's not already installed.

Default value: `$kafka::params::manage_java`

##### <a name="package_dir"></a>`package_dir`

Data type: `Stdlib::Absolutepath`

The directory to install Kafka.

Default value: `$kafka::params::package_dir`

##### <a name="package_name"></a>`package_name`

Data type: `Optional[String[1]]`

Package name, when installing Kafka from a package.

Default value: `$kafka::params::package_name`

##### <a name="package_ensure"></a>`package_ensure`

Data type: `String[1]`

Package version or ensure state, when installing Kafka from a package.

Default value: `$kafka::params::package_ensure`

##### <a name="user_name"></a>`user_name`

Data type: `String[1]`

User to run Kafka as.

Default value: `$kafka::params::user_name`

##### <a name="user_shell"></a>`user_shell`

Data type: `Stdlib::Absolutepath`

Login shell of the Kafka user.

Default value: `$kafka::params::user_shell`

##### <a name="group_name"></a>`group_name`

Data type: `String[1]`

Group to run Kafka as.

Default value: `$kafka::params::group_name`

##### <a name="user_id"></a>`user_id`

Data type: `Optional[Integer]`

Create the Kafka user with this ID.

Default value: `$kafka::params::user_id`

##### <a name="group_id"></a>`group_id`

Data type: `Optional[Integer]`

Create the Kafka group with this ID.

Default value: `$kafka::params::group_id`

##### <a name="manage_user"></a>`manage_user`

Data type: `Boolean`

Create the Kafka user if it's not already present.

Default value: `$kafka::params::manage_user`

##### <a name="manage_group"></a>`manage_group`

Data type: `Boolean`

Create the Kafka group if it's not already present.

Default value: `$kafka::params::manage_group`

##### <a name="config_mode"></a>`config_mode`

Data type: `Stdlib::Filemode`

The permissions for the config files.

Default value: `$kafka::params::config_mode`

##### <a name="config_dir"></a>`config_dir`

Data type: `Stdlib::Absolutepath`

The directory to create the Kafka config files to.

Default value: `$kafka::params::config_dir`

##### <a name="log_dir"></a>`log_dir`

Data type: `Stdlib::Absolutepath`

The directory for Kafka log files.

Default value: `$kafka::params::log_dir`

##### <a name="bin_dir"></a>`bin_dir`

Data type: `Stdlib::Absolutepath`

The directory where the Kafka scripts are.

Default value: `$kafka::params::bin_dir`

##### <a name="service_name"></a>`service_name`

Data type: `String[1]`

Set the name of the service.

Default value: `'kafka-mirror'`

##### <a name="manage_service"></a>`manage_service`

Data type: `Boolean`

Install the init.d or systemd service.

Default value: `$kafka::params::manage_service`

##### <a name="service_ensure"></a>`service_ensure`

Data type: `Enum['running', 'stopped']`

Set the ensure state of the service.

Default value: `$kafka::params::service_ensure`

##### <a name="service_restart"></a>`service_restart`

Data type: `Boolean`

Whether the configuration files should trigger a service restart.

Default value: `$kafka::params::service_restart`

##### <a name="service_requires"></a>`service_requires`

Data type: `Array[String[1]]`

Set the list of services required to be running before Kafka.

Default value: `$kafka::params::service_requires`

##### <a name="limit_nofile"></a>`limit_nofile`

Data type: `Optional[String[1]]`

Set the 'LimitNOFILE' option of the systemd service.

Default value: `$kafka::params::limit_nofile`

##### <a name="limit_core"></a>`limit_core`

Data type: `Optional[String[1]]`

Set the 'LimitCORE' option of the systemd service.

Default value: `$kafka::params::limit_core`

##### <a name="env"></a>`env`

Data type: `Hash`

A hash of the environment variables to set.

Default value: `{}`

##### <a name="consumer_config"></a>`consumer_config`

Data type: `Hash[String[1],String[1]]`

A hash of the consumer configuration options.

Default value: `{}`

##### <a name="producer_config"></a>`producer_config`

Data type: `Hash[String[1],String[1]]`

A hash of the producer configuration options.

Default value: `{}`

##### <a name="service_config"></a>`service_config`

Data type: `Hash[String[1],String[1]]`

A hash of the mirror script options.

Default value: `{}`

##### <a name="heap_opts"></a>`heap_opts`

Data type: `String[1]`

Set the Java heap size.

Default value: `$kafka::params::mirror_heap_opts`

##### <a name="jmx_opts"></a>`jmx_opts`

Data type: `String[1]`

Set the JMX options.

Default value: `$kafka::params::mirror_jmx_opts`

##### <a name="log4j_opts"></a>`log4j_opts`

Data type: `String[1]`

Set the Log4j options.

Default value: `$kafka::params::mirror_log4j_opts`

##### <a name="manage_log4j"></a>`manage_log4j`

Data type: `Boolean`



Default value: `$kafka::params::manage_log4j`

##### <a name="log_file_size"></a>`log_file_size`

Data type: `Pattern[/[1-9][0-9]*[KMG]B/]`



Default value: `$kafka::params::log_file_size`

##### <a name="log_file_count"></a>`log_file_count`

Data type: `Integer[1, 50]`



Default value: `$kafka::params::log_file_count`

### <a name="kafkaparams"></a>`kafka::params`

This class provides default parameters.

### <a name="kafkaproducer"></a>`kafka::producer`

This class handles the Kafka (producer).

#### Examples

##### Basic usage

```puppet
class { 'kafka::producer':
  config => {
    'client.id'         => '0',
    'zookeeper.connect' => 'localhost:2181'
  }
}
```

#### Parameters

The following parameters are available in the `kafka::producer` class:

* [`input`](#input)
* [`kafka_version`](#kafka_version)
* [`scala_version`](#scala_version)
* [`install_dir`](#install_dir)
* [`mirror_url`](#mirror_url)
* [`manage_java`](#manage_java)
* [`package_dir`](#package_dir)
* [`package_name`](#package_name)
* [`package_ensure`](#package_ensure)
* [`user_name`](#user_name)
* [`user_shell`](#user_shell)
* [`group_name`](#group_name)
* [`user_id`](#user_id)
* [`group_id`](#group_id)
* [`manage_user`](#manage_user)
* [`manage_group`](#manage_group)
* [`config_mode`](#config_mode)
* [`config_dir`](#config_dir)
* [`log_dir`](#log_dir)
* [`bin_dir`](#bin_dir)
* [`service_name`](#service_name)
* [`manage_service`](#manage_service)
* [`service_ensure`](#service_ensure)
* [`service_restart`](#service_restart)
* [`service_requires`](#service_requires)
* [`limit_nofile`](#limit_nofile)
* [`limit_core`](#limit_core)
* [`env`](#env)
* [`config`](#config)
* [`service_config`](#service_config)
* [`jmx_opts`](#jmx_opts)
* [`log4j_opts`](#log4j_opts)

##### <a name="input"></a>`input`

Data type: `Optional[String[1]]`

Set named pipe as input.

##### <a name="kafka_version"></a>`kafka_version`

Data type: `String[1]`

The version of Kafka that should be installed.

Default value: `$kafka::params::kafka_version`

##### <a name="scala_version"></a>`scala_version`

Data type: `String[1]`

The scala version what Kafka was built with.

Default value: `$kafka::params::scala_version`

##### <a name="install_dir"></a>`install_dir`

Data type: `Stdlib::Absolutepath`

The directory to install Kafka to.

Default value: `$kafka::params::install_dir`

##### <a name="mirror_url"></a>`mirror_url`

Data type: `Stdlib::HTTPUrl`

The url where the Kafka is downloaded from.

Default value: `$kafka::params::mirror_url`

##### <a name="manage_java"></a>`manage_java`

Data type: `Boolean`

Install java if it's not already installed.

Default value: `$kafka::params::manage_java`

##### <a name="package_dir"></a>`package_dir`

Data type: `Stdlib::Absolutepath`

The directory to install Kafka.

Default value: `$kafka::params::package_dir`

##### <a name="package_name"></a>`package_name`

Data type: `Optional[String[1]]`

Package name, when installing Kafka from a package.

Default value: `$kafka::params::package_name`

##### <a name="package_ensure"></a>`package_ensure`

Data type: `String[1]`

Package version or ensure state, when installing Kafka from a package.

Default value: `$kafka::params::package_ensure`

##### <a name="user_name"></a>`user_name`

Data type: `String[1]`

User to run Kafka as.

Default value: `$kafka::params::user_name`

##### <a name="user_shell"></a>`user_shell`

Data type: `Stdlib::Absolutepath`

Login shell of the Kafka user.

Default value: `$kafka::params::user_shell`

##### <a name="group_name"></a>`group_name`

Data type: `String[1]`

Group to run Kafka as.

Default value: `$kafka::params::group_name`

##### <a name="user_id"></a>`user_id`

Data type: `Optional[Integer]`

Create the Kafka user with this ID.

Default value: `$kafka::params::user_id`

##### <a name="group_id"></a>`group_id`

Data type: `Optional[Integer]`

Create the Kafka group with this ID.

Default value: `$kafka::params::group_id`

##### <a name="manage_user"></a>`manage_user`

Data type: `Boolean`

Create the Kafka user if it's not already present.

Default value: `$kafka::params::manage_user`

##### <a name="manage_group"></a>`manage_group`

Data type: `Boolean`

Create the Kafka group if it's not already present.

Default value: `$kafka::params::manage_group`

##### <a name="config_mode"></a>`config_mode`

Data type: `Stdlib::Filemode`

The permissions for the config files.

Default value: `$kafka::params::config_mode`

##### <a name="config_dir"></a>`config_dir`

Data type: `Stdlib::Absolutepath`

The directory to create the Kafka config files to.

Default value: `$kafka::params::config_dir`

##### <a name="log_dir"></a>`log_dir`

Data type: `Stdlib::Absolutepath`

The directory for Kafka log files.

Default value: `$kafka::params::log_dir`

##### <a name="bin_dir"></a>`bin_dir`

Data type: `Stdlib::Absolutepath`

The directory where the Kafka scripts are.

Default value: `$kafka::params::bin_dir`

##### <a name="service_name"></a>`service_name`

Data type: `String[1]`

Set the name of the service.

Default value: `'kafka-producer'`

##### <a name="manage_service"></a>`manage_service`

Data type: `Boolean`

Install the init.d or systemd service.

Default value: `$kafka::params::manage_service`

##### <a name="service_ensure"></a>`service_ensure`

Data type: `Enum['running', 'stopped']`

Set the ensure state of the service.

Default value: `$kafka::params::service_ensure`

##### <a name="service_restart"></a>`service_restart`

Data type: `Boolean`

Whether the configuration files should trigger a service restart.

Default value: `$kafka::params::service_restart`

##### <a name="service_requires"></a>`service_requires`

Data type: `Array[String[1]]`

Set the list of services required to be running before Kafka.

Default value: `$kafka::params::service_requires`

##### <a name="limit_nofile"></a>`limit_nofile`

Data type: `Optional[String[1]]`

Set the 'LimitNOFILE' option of the systemd service.

Default value: `$kafka::params::limit_nofile`

##### <a name="limit_core"></a>`limit_core`

Data type: `Optional[String[1]]`

Set the 'LimitCORE' option of the systemd service.

Default value: `$kafka::params::limit_core`

##### <a name="env"></a>`env`

Data type: `Hash`

A hash of the environment variables to set.

Default value: `{}`

##### <a name="config"></a>`config`

Data type: `Hash[String[1], Any]`

A hash of the producer configuration options.

Default value: `{}`

##### <a name="service_config"></a>`service_config`

Data type: `Hash[String[1],String[1]]`

A hash of the `kafka-console-producer.sh` script options.

Default value: `{}`

##### <a name="jmx_opts"></a>`jmx_opts`

Data type: `String[1]`

Set the JMX options.

Default value: `$kafka::params::producer_jmx_opts`

##### <a name="log4j_opts"></a>`log4j_opts`

Data type: `String[1]`

Set the Log4j options.

Default value: `$kafka::params::producer_log4j_opts`

### <a name="kafkaproducerconfig"></a>`kafka::producer::config`

This class handles the Kafka (producer) config.

#### Parameters

The following parameters are available in the `kafka::producer::config` class:

* [`manage_service`](#manage_service)
* [`service_name`](#service_name)
* [`service_restart`](#service_restart)
* [`config`](#config)
* [`config_dir`](#config_dir)
* [`user_name`](#user_name)
* [`group_name`](#group_name)
* [`config_mode`](#config_mode)

##### <a name="manage_service"></a>`manage_service`

Data type: `Boolean`



Default value: `$kafka::producer::manage_service`

##### <a name="service_name"></a>`service_name`

Data type: `String[1]`



Default value: `$kafka::producer::service_name`

##### <a name="service_restart"></a>`service_restart`

Data type: `Boolean`



Default value: `$kafka::producer::service_restart`

##### <a name="config"></a>`config`

Data type: `Hash[String[1], Any]`



Default value: `$kafka::producer::config`

##### <a name="config_dir"></a>`config_dir`

Data type: `Stdlib::Absolutepath`



Default value: `$kafka::producer::config_dir`

##### <a name="user_name"></a>`user_name`

Data type: `String[1]`



Default value: `$kafka::producer::user_name`

##### <a name="group_name"></a>`group_name`

Data type: `String[1]`



Default value: `$kafka::producer::group_name`

##### <a name="config_mode"></a>`config_mode`

Data type: `Stdlib::Filemode`



Default value: `$kafka::producer::config_mode`

## Defined types

### <a name="kafkatopic"></a>`kafka::topic`

This defined type handles the creation of Kafka topics.

#### Examples

##### Basic usage

```puppet
kafka::topic { 'test':
  ensure             => present,
  zookeeper          => 'localhost:2181',
  replication_factor => 1,
  partitions         => 1,
}
```

#### Parameters

The following parameters are available in the `kafka::topic` defined type:

* [`ensure`](#ensure)
* [`zookeeper`](#zookeeper)
* [`replication_factor`](#replication_factor)
* [`partitions`](#partitions)
* [`bin_dir`](#bin_dir)
* [`config`](#config)

##### <a name="ensure"></a>`ensure`

Data type: `String[1]`

Should the topic be created.

Default value: `''`

##### <a name="zookeeper"></a>`zookeeper`

Data type: `String[1]`

The connection string for the ZooKeeper connection in the form host:port.
Multiple hosts can be given to allow fail-over.

Default value: `''`

##### <a name="replication_factor"></a>`replication_factor`

Data type: `Integer`

The replication factor for each partition in the topic being created. If
not supplied, defaults to the cluster default.

Default value: `1`

##### <a name="partitions"></a>`partitions`

Data type: `Integer`

The number of partitions for the topic being created or altered. If not
supplied for create, defaults to the cluster default.

Default value: `1`

##### <a name="bin_dir"></a>`bin_dir`

Data type: `String[1]`

The directory where the file kafka-topics.sh is located.

Default value: `'/opt/kafka/bin'`

##### <a name="config"></a>`config`

Data type: `Optional[Hash[String[1],String[1]]]`

A topic configuration override for the topic being created or altered.
See the Kafka documentation for full details on the topic configs.

Default value: ``undef``

